==> phpwebthings-0.6.0.zip: phpwebthings-0.6.0/lang/msg_fr.php <==
<?php
// french file for phpwebthings - Eric Courtes <eric.courtes@wanadoo.fr>
$lang = array(
"CHARSET"=>"iso-8859-1",
//general
"ACTIVATE_TITLE"=>"Compte activ!",
"ADD_USERS"=>"Ajouter utilisateurs",
"REPLIES_TO"=>"Rpondre ",
"PREVIOUS_MSG"=>"Prcdent message sur ce sujet",
"BACK_FORUM"=>"Retour au forum",
"OPTION_NONE"=>"aucune",
"GO_BACK"=>"Retour",
"PAGE_PROCESSED"=>"Page processed in %.4f seconds",

// general not logged
"NOT_LOGGED_ONLINE"=>"Dsol, mais vous devez tre logu pour voir les utilisateurs en ligne. Si vous n'avez pas de compte, pourquoi ne pas s'inscrire ? C'est gratuit !",
"NOT_LOGGED_MYACCT"=>"Dsol, mais vous devez vous logu pour modifier votre compte. Si vous n'avez pas de compte, pourquoi ne pas s'inscrire ? C'est gratuit !",

//home
"HOME_TITLE"=>"Accueil",

//error messages
"ERROR_TITLE"=>"*** ERREUR ***",
"ERROR_01"=>"Vous ne pouvez envoyer un message sans sujet et/ou texte",
"ERROR_02"=>"Vous devez fournir un titre<br>",
"ERROR_03"=>"Vous devez fournir un texte<br>",
"ERROR_04"=>"Une erreur est survenue au lancement des commandes SQL",
"ERROR_05"=>"Erreur  l'ouverture du rpertoire",
"ERROR_06"=>"bannire introuvable",
"ERROR_07"=>"fichier introuvable",
"ERROR_08"=>"E-mail incorrect<br>",
"ERROR_09"=>"E-mail introuvable!<br>",
"ERROR_10"=>"Parser error: ",
"ERROR_11"=>"Action denied",

// not logged messages
//NOT_LOGGED_ONLINE
//NOT_LOGGED_MYACCT

// MyAccount / NewUser
"MYACCT_TITLE"=>"Mon Compte",
"MYACCT_INFO"=>"Informations sur Mon Compte",
"MYACCT_TEXT"=>"Toutes les informations saisient ici (sauf e-mail) sont visibles par les autres utilisateurs incrits.",
"MYACCT_FORM_LOGIN"=>"Pseudo",
"MYACCT_FORM_REALNAME"=>"Nom",
"MYACCT_FORM_PASSWD_INFO"=>"Si vous ne voulez pas modifier votre mot de passe, laissez le champ mot de passe  blanc",
"MYACCT_FORM_PASSWD"=>"Mot de passe",
"MYACCT_FORM_PASSWD2"=>"Confirmation Mot de passe",
"MYACCT_FORM_EMAIL"=>"E-mail (le compte sera activ par un message)",
"MYACCT_FORM_SEX"=>"Sexe",
"MYACCT_FORM_COUNTRY"=>"Pays",
"MYACCT_FORM_CITY"=>"Ville",
"MYACCT_FORM_STATE"=>"Dpartement/Rgion",
"MYACCT_FORM_RCVNEWS"=>"Recevoir les nouvelles de ce site sur votre messagerie ?",
"MYACCT_FORM_RCVREL"=>"Recevoir un message lorsqu'un nouveau fichier est disponible ?",
"MYACCT_FORM_URL"=>"Votre site: (dbute par http://)",
"MYACCT_FORM_OBS"=>"Commentaires  votre sujet :",
"MYACCT_FORM_SUBMIT"=>"Transmettre",
"MYACCT_NEWSPOSTED"=>"Nouvelles envoys",
"MYACCT_COMMENTSPOSTED"=>"Commentaires envoys",
"MYACCT_FAQPOSTED"=>"FAQs envoys",
"MYACCT_DATEACTIVATED"=>"Membre depuis",
"MYACCT_LASTVISIT"=>"Dernire connection",
"MYACCT_NUMLOGINS"=>"Total visites",
"MYACCT_LOGGED"=>"Vous ne pouvez pas vous inscrire car vous tes dj inscrit sur ce site.",

"MYACCT_USER_BOOK"=>"Ma liste utilisateur",
"MYACCT_ADD_USER"=>"ajouter cet utilisateur dans mon carnet",
"MYACCT_USER_ADDED"=>"Utilisateur ajout",
"MYACCT_DEL_USER"=>"supprimer cet utilisateur de mon carnet",
"MYACCT_USER_DELETED"=>"Utilisateur supprim du carnet",
"MYACCT_PROFILE"=>"Profil utilisateur pour",

"MYACCT_INS_ERROR_01"=>"Vous devez saisir un mot de passe",
"MYACCT_INS_ERROR_02"=>"Les mots de passe saisient sont diffrents",
"MYACCT_INS_ERROR_03"=>"Veuillez saisir votre nom",
"MYACCT_INS_ERROR_04"=>"Veuillez utiliser des caractres alphanumeric ou \'_,.,-\' pour le nom",
"MYACCT_INS_ERROR_05"=>"Veuillez saisir un pays",
"MYACCT_INS_ERROR_06"=>"Cet email est dja enregistr !<br>Si vous voulez le supprimer de la base,<br> envoy un message ",
"MYACCT_INS_ERROR_07"=>"Cette connection est dj enregistr !<br>Veuillez choisir un autre nom",
"MYACCT_INVALID_VALUE"=>"Valeur invalide pour la question",
"MYACCT_EMAIL_CHANGED_TITLE"=>"E-mail modifi",
"MYACCT_EMAIL_CHANGED_TEXT"=>"Votre e-mail sera disponible une fois valid. Dans quelques minutes vous allez recevoir des instructions pour valider votre nouvel email  (%s). <b>En attendant votre ancien e-mail est toujours actif.</b>",
"MYACCT_EMAIL_CHANGED_MAIL_TITLE"=>"E-mail en cours de modification  %s",
"MYACCT_EMAIL_CHANGED_MAIL_TEXT"=>"Bonjour %s!\nModification d'e-mail en cours sur le site %s !\nPour activer votre nouvel e-mail, cliquer sur %s\n\nSalutations,%s",
"MYACCT_EMAIL_CHANGED_OK"=>"Votre e-mail a t modifi !",
"MYACCT_EMAIL_CHANGED_ERROR"=>"Utilisateur/session invalide.");

"NEWUSER_TITLE"=>"Nouvelle utilisateur",
"NEWUSER_MAIL_TITLE"=>"%s enregistrement",
"NEWUSER_MAIL_TEXT"=>"Bonjour %s!\nMerci de s'tre inscrit  ce site %s !\nPour activer votre compte, rendez-vous  %s\n\nMes meilleurs salutations,%s",
"NEWUSER_MSG_TITLE"=>"Vous tes presque inscrit",
"NEWUSER_MSG_TEXT"=>"<b>Merci</b> de vous tre inscrit sur notre site !<br><br>Votre compte n'est pas encore actif, dans quelques minutes vous recevrez un message vous expliquant comment l'activ.",
"NEWUSER_MSG_TITLE2"=>"Merci de votre inscription !",
"NEWUSER_MSG_TEXT2"=>"<b>Merci</b> pour vous tre inscrit sur notre site!<br><br>Maintenant vous pouvez vous connecter sur notre site.",
"NEWUSER_FORM_TITLE"=>"Inscription",
"NEWUSER_ACTIVATE_ERROR"=>"Utilisateur/session incorrecte ou compte dj cr.");
"NEWUSER_ACTIVATED"=>"Votre compte a t activ! Maintenant vous pouvez envoyer des messages dans les forums et  d'autres utilisateurs sur ce site. Pour voir la lise des utilisateurs et les ajouter  votre carnet d'adresse rendez-vous  \"Mon Compte\" et cliqu sur \"ajouter utilisateurs\".<br><br>Merci de vous tre inscrit !");
"NEW_USER_LINK"=>"Inscription",
//Login
"LOGIN_TITLE"=>"Connection",
"LOGIN_NAME"=>"Pseudo:",
"LOGIN_PASSWD"=>"Mot de passe:",
"LOGIN_BUTTON"=>"Connection",
"LOGIN_REGISTER"=>"Inscription gratuite!",
"LOGIN_LOST_PWD"=>"Mot de passe oubli ?",
"LOGIN_WELCOME"=>"Bienvenue %s",
"LOGIN_LOGOUT"=>"dconnection",
"LOGIN_AUTOLOGIN"=>"mmoris",

//Users online
"USERS_ONLINE"=>"Utilisateurs En Ligne",
"USERS_ONLINE_TEXT"=>"Il y a :<br>%d utilisateurs inscrits<br>et %d htes %sonline%s actuellement.",

//List users
"LIST_USERS_TITLE"=>"Listes Utilisateurs",

// Lost your password?
"PASSWD_TITLE"=>"Retrouver le Mot de passe",
"PASSWD_MAIL_TITLE"=>"Mot de passe retrouv  ",
"PASSWD_MAIL_TEXT1"=>"Vous m'avez demand que je vous transmette votre mote de passe  %s\n\npeudo: %s\nmot de passe: %s",
"PASSWD_MAIL_TEXT2"=>"Mais votre compte n'est pas activ, pour activer votre compte, veuillez vous rendre  la page ci-dessous:\n",
"PASSWD_MAIL_DONE"=>"Un message vous a t envoy avec votre pseudo.",
"PASSWD_MAIL_ERROR"=>"N'ai pas pu vous envoyer le message. Error interne.<br>",
"PASSWD_TEXT"=>"Mot de passe perdu ? Nous vous l'envoyons ! Remplissez seulement le formulaire avec votre email et nous vous enverrons un message avec votre pseudo. Utilisez seulement pour retrouver VOTRE mot de passe.",
"PASSWD_FORM_EMAIL"=>"E-mail:",
"PASSWD_FORM_SUBMIT"=>"Retrouver Mot de Passe",

//stats
"STATS_TITLE"=>"Statistiques",
"STATS_USERS"=>"Utilisateurs inscrits",
"STATS_ACTIVE"=>"Actif",
"STATS_NOTACTIVE"=>"Non actif",
"STATS_TOTAL"=>"Total",
"STATS_TOPTEN"=>"Top10 des Pays",
"STATS_DESKOS"=>"SE Bureau",
"STATS_SERVOS"=>"SE Serveur",
"STATS_LAST_WEEK"=>"Nouveaux utilisateurs cette semaine",
"STATS_LAST_MONTHS"=>"Nouveaux utilisateurs / 3 mois",

//send e-mail
"SENDMAIL_MSG_HDR"=>"Bonjour, %s', \n\n",
"SENDMAIL_MSG_FTR"=>"\n\nAu revoir,\n\n%s\n\nCe message a t envoy car vous tes inscrit  %s. Si vous ne voulez recevoir aucun message de notre part, veuillez envoyez un message  %s indiquant que vous souhaitez tre supprim de la liste.",
"SENDMAIL_MAIL_SENT"=>"envoy",
"SENDMAIL_USER"=>"Utilisateur",
"SENDMAIL_EMAIL"=>"E-mail",
"SENDMAIL_COUNTRY"=>"Pays",
"SENDMAIL_SEND"=>"Envoy",
"SENDMAIL_TEXT"=>"Texte",
"SENDMAIL_SUBMIT"=>"Envoyer message",
"SENDMAIL_ACCTO"=>"Send e-mail to users that:",
"SENDMAIL_ACCNEWS"=>"Accepts news",
"SENDMAIL_ACCFREL"=>"Accepts new file releases",
"SENDMAIL_CONTINUE"=>"Continue sending",

// Avatars
"AVATAR_TITLE"=>"Choose your Avatar",
"AVATAR_NONE"=>"none/remove current",
"AVATAR_SELECT"=>"Select your avatar:",
"AVATAR_UPLOAD"=>"or upload a new avatar: (100x100).(jpg|gif|png)",
);

?>

==> phpwebthings-1.0.zip: phpwebthings-1.0/lang/msg_fr.php <==
<?php
// french file for phpwebthings - Eric Courtes <eric.courtes@wanadoo.fr>
$lang = array(
"CHARSET"=>"iso-8859-1",
//general
"ACTIVATE_TITLE"=>"Compte activ!",
"ADD_USERS"=>"Ajouter utilisateurs",
"REPLIES_TO"=>"Rpondre ",
"PREVIOUS_MSG"=>"Prcdent message sur ce sujet",
"BACK_FORUM"=>"Retour au forum",
"OPTION_NONE"=>"aucune",
"GO_BACK"=>"Retour",
"PAGE_PROCESSED"=>"Cration de la page en %.4f secondes",

// general not logged
"NOT_LOGGED_ONLINE"=>"Dsol, mais vous devez tre logu pour voir les utilisateurs en ligne. Si vous n'avez pas de compte, pourquoi ne pas s'inscrire ? C'est gratuit !",
"NOT_LOGGED_MYACCT"=>"Dsol, mais vous devez vous logu pour modifier votre compte. Si vous n'avez pas de compte, pourquoi ne pas s'inscrire ? C'est gratuit !",
"NOT_LOGGED"=>"We apologize, but you need to login to use this feature. If you don't have an account, why don't you register? It's free!",

//home
"HOME_TITLE"=>"Accueil",

//error messages
"ERROR_TITLE"=>"*** ERREUR ***",
"ERROR_01"=>"Vous ne pouvez envoyer un message sans sujet et/ou texte",
"ERROR_02"=>"Vous devez fournir un titre<br>",
"ERROR_03"=>"Vous devez fournir un texte<br>",
"ERROR_04"=>"Une erreur est survenue au lancement des commandes SQL",
"ERROR_05"=>"Erreur  l'ouverture du rpertoire",
"ERROR_06"=>"bannire introuvable",
"ERROR_07"=>"fichier introuvable",
"ERROR_08"=>"Courriel incorrect<br>",
"ERROR_09"=>"Courriel introuvable!<br>",
"ERROR_10"=>"Parser error: ",
"ERROR_11"=>"Action refus",

// not logged messages
//NOT_LOGGED_ONLINE
//NOT_LOGGED_MYACCT

// MyAccount / NewUser
"MYACCT_TITLE"=>"Mon Compte",
"MYACCT_INFO"=>"Informations sur Mon Compte",
"MYACCT_TEXT"=>"Toutes les informations saisient ici (sauf courriel) sont visibles par les autres utilisateurs incrits.",
"MYACCT_FORM_LOGIN"=>"Pseudo",
"MYACCT_FORM_REALNAME"=>"Nom",
"MYACCT_FORM_PASSWD_INFO"=>"Si vous ne voulez pas modifier votre mot de passe, laissez le champ mot de passe  blanc",
"MYACCT_FORM_PASSWD"=>"Mot de passe",
"MYACCT_FORM_PASSWD2"=>"Confirmation Mot de passe",
"MYACCT_FORM_EMAIL"=>"Courriel (le compte sera activ par un message)",
"MYACCT_FORM_SEX"=>"Sexe",
"MYACCT_FORM_COUNTRY"=>"Pays",
"MYACCT_FORM_CITY"=>"Ville",
"MYACCT_FORM_STATE"=>"Dpartement/Rgion",
"MYACCT_FORM_RCVNEWS"=>"Recevoir les nouvelles de ce site sur votre messagerie ?",
"MYACCT_FORM_RCVREL"=>"Recevoir un message lorsqu'un nouveau fichier est disponible ?",
"MYACCT_FORM_URL"=>"Votre site: (dbute par http://)",
"MYACCT_FORM_OBS"=>"Commentaires  votre sujet :",
"MYACCT_FORM_SUBMIT"=>"Transmettre",
"MYACCT_NEWSPOSTED"=>"Nouvelles envoys",
"MYACCT_COMMENTSPOSTED"=>"Commentaires envoys",
"MYACCT_FAQPOSTED"=>"FAQs envoys",
"MYACCT_DATEACTIVATED"=>"Membre depuis",
"MYACCT_LASTVISIT"=>"Dernire connection",
"MYACCT_NUMLOGINS"=>"Total visites",
"MYACCT_LOGGED"=>"Vous ne pouvez pas vous inscrire car vous tes dj inscrit sur ce site.",

"MYACCT_USER_BOOK"=>"Ma liste utilisateur",
"MYACCT_ADD_USER"=>"ajouter cet utilisateur dans mon carnet",
"MYACCT_USER_ADDED"=>"Utilisateur ajout",
"MYACCT_DEL_USER"=>"supprimer cet utilisateur de mon carnet",
"MYACCT_USER_DELETED"=>"Utilisateur supprim du carnet",
"MYACCT_PROFILE"=>"Profil utilisateur pour",

"MYACCT_INS_ERROR_01"=>"Vous devez saisir un mot de passe",
"MYACCT_INS_ERROR_02"=>"Les mots de passe saisient sont diffrents",
"MYACCT_INS_ERROR_03"=>"Veuillez saisir votre nom",
"MYACCT_INS_ERROR_04"=>"Veuillez utiliser des caractres alphanumeric ou \'_,.,-\' pour le nom",
"MYACCT_INS_ERROR_05"=>"Veuillez saisir un pays",
"MYACCT_INS_ERROR_06"=>"Cet email est dja enregistr !<br>Si vous voulez le supprimer de la base,<br> envoy un message ",
"MYACCT_INS_ERROR_07"=>"Cette connection est dj enregistr !<br>Veuillez choisir un autre nom",
"MYACCT_INVALID_VALUE"=>"Valeur invalide pour la question",
"MYACCT_EMAIL_CHANGED_TITLE"=>"Courriel modifi",
"MYACCT_EMAIL_CHANGED_TEXT"=>"Votre courriel sera disponible une fois valid. Dans quelques minutes vous allez recevoir des instructions pour valider votre nouvel email  (%s). <b>En attendant votre ancien courriel est toujours actif.</b>",
"MYACCT_EMAIL_CHANGED_MAIL_TITLE"=>"Courriel en cours de modification  %s",
"MYACCT_EMAIL_CHANGED_MAIL_TEXT"=>"Bonjour %s!\nModification d'courriel en cours sur le site %s !\nPour activer votre nouvel courriel, cliquer sur %s\n\nSalutations,%s",
"MYACCT_EMAIL_CHANGED_OK"=>"Votre courriel a t modifi !",
"MYACCT_EMAIL_CHANGED_ERROR"=>"Utilisateur/session invalide.",

"NEWUSER_TITLE"=>"Nouvelle utilisateur",
"NEWUSER_MAIL_TITLE"=>"%s enregistrement",
"NEWUSER_MAIL_TEXT"=>"Bonjour %s!\nMerci de s'tre inscrit  ce site %s !\nPour activer votre compte, rendez-vous  %s\n\nMes meilleurs salutations,%s",
"NEWUSER_MSG_TITLE"=>"Vous tes presque inscrit",
"NEWUSER_MSG_TEXT"=>"<b>Merci</b> de vous tre inscrit sur notre site !<br><br>Votre compte n'est pas encore actif, dans quelques minutes vous recevrez un message vous expliquant comment l'activ.",
"NEWUSER_MSG_TITLE2"=>"Merci de votre inscription !",
"NEWUSER_MSG_TEXT2"=>"<b>Merci</b> pour vous tre inscrit sur notre site!<br><br>Maintenant vous pouvez vous connecter sur notre site.",
"NEWUSER_FORM_TITLE"=>"Inscription",
"NEWUSER_ACTIVATE_ERROR"=>"Utilisateur/session incorrecte ou compte dj cr.",
"NEWUSER_ACTIVATED"=>"Votre compte a t activ! Maintenant vous pouvez envoyer des messages dans les forums et  d'autres utilisateurs sur ce site. Pour voir la lise des utilisateurs et les ajouter  votre carnet d'adresse rendez-vous  \"Mon Compte\" et cliqu sur \"ajouter utilisateurs\".<br><br>Merci de vous tre inscrit !",
"NEW_USER_LINK"=>"Inscription",
//Login
"LOGIN_TITLE"=>"Connection",
"LOGIN_NAME"=>"Pseudo:",
"LOGIN_PASSWD"=>"Mot de passe:",
"LOGIN_BUTTON"=>"Connection",
"LOGIN_REGISTER"=>"Inscription gratuite!",
"LOGIN_LOST_PWD"=>"Mot de passe oubli ?",
"LOGIN_WELCOME"=>"Bienvenue %s",
"LOGIN_LOGOUT"=>"dconnection",
"LOGIN_AUTOLOGIN"=>"mmoris",

//Users online
"USERS_ONLINE"=>"Utilisateurs En Ligne",
"USERS_ONLINE_TEXT"=>"Il y a %d Utilisateur(s)<br>et %d invit(s) <b><i> %sen ligne%s</i></b>.",
//List users
"LIST_USERS_TITLE"=>"Liste des Utilisateurs",

// Lost your password?
"PASSWD_TITLE"=>"Retrouver le Mot de passe",
"PASSWD_MAIL_TITLE"=>"Mot de passe retrouv  ",
"PASSWD_MAIL_TEXT1"=>"Vous m'avez demand que je vous transmette votre mote de passe  %s\n\npeudo: %s\nmot de passe: %s",
"PASSWD_MAIL_TEXT2"=>"Mais votre compte n'est pas activ, pour activer votre compte, veuillez vous rendre  la page ci-dessous:\n",
"PASSWD_MAIL_DONE"=>"Un message vous a t envoy avec votre pseudo.",
"PASSWD_MAIL_ERROR"=>"N'ai pas pu vous envoyer le message. Error interne.<br>",
"PASSWD_TEXT"=>"Mot de passe perdu ? Nous vous l'envoyons ! Remplissez seulement le formulaire avec votre email et nous vous enverrons un message avec votre pseudo. Utilisez seulement pour retrouver VOTRE mot de passe.",
"PASSWD_FORM_EMAIL"=>"Courriel:",
"PASSWD_FORM_SUBMIT"=>"Retrouver Mot de Passe",

//stats
"STATS_TITLE"=>"Statistiques",
"STATS_USERS"=>"Utilisateurs inscrits",
"STATS_ACTIVE"=>"Actif",
"STATS_NOTACTIVE"=>"Non actif",
"STATS_TOTAL"=>"Total",
"STATS_TOPTEN"=>"Top10 des Pays",
"STATS_DESKOS"=>"SE Bureau",
"STATS_SERVOS"=>"SE Serveur",
"STATS_LAST_WEEK"=>"Nouveaux utilisateurs cette semaine",
"STATS_LAST_MONTHS"=>"Nouveaux utilisateurs / 3 mois",

//send courriel
"SENDMAIL_MSG_HDR"=>"Bonjour, %s', \n\n",
"SENDMAIL_MSG_FTR"=>"\n\nAu revoir,\n\n%s\n\nCe message a t envoy car vous tes inscrit  %s. Si vous ne voulez recevoir aucun message de notre part, veuillez envoyez un message  %s indiquant que vous souhaitez tre supprim de la liste.",
"SENDMAIL_MAIL_SENT"=>"envoy",
"SENDMAIL_USER"=>"Utilisateur",
"SENDMAIL_EMAIL"=>"Courriel",
"SENDMAIL_COUNTRY"=>"Pays",
"SENDMAIL_SEND"=>"Envoy",
"SENDMAIL_TEXT"=>"Texte",
"SENDMAIL_SUBMIT"=>"Envoyer message",
"SENDMAIL_ACCTO"=>"Send courriel to users that:",
"SENDMAIL_ACCNEWS"=>"Accepts news",
"SENDMAIL_ACCFREL"=>"Accepts new file releases",
"SENDMAIL_CONTINUE"=>"Continue sending",

// Avatars
"AVATAR_TITLE"=>"Votre image",
"AVATAR_NONE"=>"Aucune",
"AVATAR_SELECT"=>"Slectionner votre image:",
"AVATAR_UPLOAD"=>"ou transfrer votre image: (100x100).(jpg|gif|png)",

// Admmenu
"ADMMNU_INFO"=>"Info",
"ADMMNU_WEBADMIN"=>"WebAdmin",
"ADMMNU_SENDEMAIL"=>"Send e-mail",
"ADMMNU_USERS"=>"Users",
"ADMMNU_USERACCESS"=>"User Access",
"ADMMNU_MENU"=>"Menu",

"SIDEBOX_EDIT_TITLE"=>"Side Boxes"
);

?>
